@@ -58,6 +58,11 @@ setMethod("export", c("ANY", "WIGFile"),
               row.names = FALSE, quote = FALSE)
 }
 
+isValidScore <- function(score) {
+    !(is.numeric(score) || is(score, "Rle") && is.numeric(runValue(score))) ||
+        any(is.na(score))
+}
+
 setMethod("export", c("GenomicRanges", "WIGFile"),
           function(object, con, format,
                    dataFormat = c("auto", "variableStep", "fixedStep"),
@@ -65,7 +70,7 @@ setMethod("export", c("GenomicRanges", "WIGFile"),
           {
             if (!missing(format))
               checkArgFormat(con, format)
-            if (!is.numeric(score(object)) || any(is.na(score(object))))
+            if (isValidScore(score(object)))
               stop("The score must be numeric, without any NA's")
             scipen <- getOption("scipen")
             options(scipen = 100) # prevent use of scientific notation
@@ -73,7 +78,12 @@ setMethod("export", c("GenomicRanges", "WIGFile"),
             dataFormat <- match.arg(dataFormat)            
             doBlock <- function(chromData) {
               if (length(chromData) == 0L)
-                return()
+                  return()
+              if (is(chromData, "GPos")) {
+                  ans <- writer(chromData, con, "fixedStep", append)
+                  append <<- TRUE
+                  return(ans)
+              }
               if (is.unsorted(start(chromData)))
                 chromData <- chromData[order(start(chromData)),]
               starts <- start(chromData)
